@@ -5,4 +5,4 @@ __doc__ = """
 from .config import Config, SaynConfigError
 from .dag import Dag, DagValidationError
 from .tasks import PythonTask
-from .utils.logger import Logger
+from .utils.ui import UI
