@@ -2,12 +2,11 @@ from copy import copy, deepcopy
 from collections import deque, OrderedDict
 from datetime import datetime
 from itertools import groupby
-import logging
 import sys
 
 from .config import Config
 from .utils.singleton import singleton
-from .utils.logger import Logger
+from .utils.ui import UI
 from .tasks import create_task, TaskStatus, IgnoreTask
 
 
@@ -23,11 +22,6 @@ class Dag:
     tasks = dict()
 
     def __init__(self, tasks_query=(), exclude_query=()):
-        Logger().set_config(stage="DAG")
-        logging.info("----------")
-        logging.info(f"Setting up. Run ID: {Config().run_id}")
-        logging.info("----------")
-
         task_definitions = Config()._task_definitions
 
         # Setup DAG structure using just names and parents
@@ -103,15 +97,13 @@ class Dag:
 
         # Run the setup for each task
         for _, task in self.tasks.items():
-            Logger().set_config(task=task.name)
+            UI()._set_config(task_name=task.name)
             if task.status == TaskStatus.FAILED:
                 continue
             task.setup()
 
         # delete the task_definitions attribute from the config so it we do not have tasks on both APIs
         # delattr(Config(), "_task_definitions")
-        Logger().set_config(task=None)
-        logging.info("DAG Setup: done.")
 
     def _task_query(self, tags, dags, query):
         """Returns a list of tasks from the dag matching the query"""
@@ -152,16 +144,20 @@ class Dag:
             # ... or the task doesn't exists in the dag
             raise KeyError(f'Task "{query}" not in dag')
 
-    def _run_task(self, command, task):
-        Logger().set_config(task=task.name)
+    def _run_task(self, command, task, tcounter, ntasks):
+        progress = "(" + str(tcounter) + "/" + str(ntasks) + ")"
+        ui = UI()
+        ui._set_config(stage_name="run", task_name=task.name, progress=progress)
+        ui.info("Starting.")
         task_start_ts = datetime.now()
         if task.status != TaskStatus.READY:
-            task.failed("Task failed during setup. Skipping...")
+            task.failed()
+            ui._status_fail("Task failed during setup.")
         elif not task.can_run():
-            logging.warn("SKIPPING")
             task.skipped()
+            ui._status_warn("SKIPPING")
         else:
-            logging.debug("Starting")
+            ui.debug("Starting")
             task.executing()
             try:
                 if command == "compile":
@@ -171,29 +167,25 @@ class Dag:
                 else:
                     status = None
             except Exception as e:
-                logging.exception(e)
+                ui.error(e)
 
                 status = None
 
             if status is None:
                 task.status = TaskStatus.UNKNOWN
-                logging.error(
-                    f"Finished in an unknown state ({datetime.now() - task_start_ts})"
+                ui._status_fail(
+                    f"finished in an unknown state ({datetime.now() - task_start_ts})"
                 )
             elif status != TaskStatus.SUCCESS:
-                logging.error(f"Failed status ({datetime.now() - task_start_ts})")
+                ui._status_fail(f"{datetime.now() - task_start_ts}")
             else:
-                logging.info(
-                    f"\u001b[32mSuccess ({datetime.now() - task_start_ts})\u001b[0m"
-                )
+                ui._status_success(f"{datetime.now() - task_start_ts}")
 
         return task.status
 
     def _run_command(self, command):
-        Logger().set_config(stage="Run", task=None, progress="0")
-        logging.info("----------")
-        logging.info(f"Running. Run ID: {Config().run_id}")
-        logging.info("----------")
+        ui = UI()
+        ui._set_config(stage_name="run", task_name=None, progress=None)
 
         failed = list()
         success = list()
@@ -204,29 +196,25 @@ class Dag:
         ]
         ntasks = len(tasks_to_run)
 
-        tcounter = 0
+        tcounter = 1
         for task in self.tasks.values():
             if not task.should_run():
                 # For IgnoreTasks
                 task.success()
                 continue
 
-            status = self._run_task(command, task)
+            status = self._run_task(command, task, tcounter, ntasks)
             if status == TaskStatus.SKIPPED:
                 skipped.append(task.name)
-            elif status in (TaskStatus.FAILED, TaskStatus.UNKNOWN) or status != TaskStatus.SUCCESS:
+            elif (
+                status in (TaskStatus.FAILED, TaskStatus.UNKNOWN)
+                or status != TaskStatus.SUCCESS
+            ):
                 failed.append(task.name)
             else:
                 success.append(task.name)
 
             tcounter += 1
-            run_progress = str(round((tcounter) / ntasks * 100))
-            Logger().set_config(progress=run_progress)
-
-        Logger().set_config(stage="Summary", task=None, progress=None)
-        logging.info("----------")
-        logging.info(f"Stats for Run ID: {Config().run_id}")
-        logging.info("----------")
 
         recap_str = list()
         recap_str.append(
@@ -239,12 +227,15 @@ class Dag:
         if len(skipped) > 0:
             recap_str.append(f"The following tasks were skipped: {', '.join(skipped)}")
 
+        ui = UI()
+        ui._set_config(stage_name="summary", task_name=None, progress=None)
+
         if len(failed) > 0:
-            log_func = logging.error
+            log_func = lambda x: ui._status_fail(x)
         elif len(skipped) > 0:
-            log_func = logging.warning
+            log_func = lambda x: ui._status_warning(x)
         else:
-            log_func = lambda x: logging.info(f"\u001b[32m{x}\u001b[0m")
+            log_func = lambda x: ui._status_success(x)
 
         for msg in recap_str:
             log_func(msg)
@@ -266,7 +257,7 @@ class Dag:
         try:
             from graphviz import Digraph
         except:
-            logging.error(
+            UI().error(
                 "Graphviz is required. To install it `pip install graphviz` and install it in your system (eg: `brew install graphviz"
             )
             sys.exit()
