@@ -1,6 +1,5 @@
-import logging
-
 from .task import Task
+from ..utils.ui import UI
 
 
 class PythonTask(Task):
@@ -10,14 +9,17 @@ class PythonTask(Task):
         # Add some convenient properties
         self.default_db = self.sayn_config.default_db
 
+        # Add UI
+        self.logger = UI()
+
     def setup(self):
-        logging.debug("Setting up Python Task")
+        UI().debug("Setting up Python Task")
         return self.ready()
 
     def compile(self):
-        logging.debug("PythonTask compiling")
+        UI().debug("PythonTask compiling")
         return self.success()
 
     def run(self):
-        logging.debug("PythonTask running.")
+        UI().debug("PythonTask running.")
         return self.success()
